#[repr(transparent)]pub struct PreChargeTime(pub u32);Expand description
Pre-charge Time
Tuple Fields
0: u32Implementations
Sourceimpl PreChargeTime
impl PreChargeTime
Sourcepub const fn pre_charge_time(&self) -> u32
pub const fn pre_charge_time(&self) -> u32
Before detection, the top screen needs some time before being pulled up to a high voltage.
Sourcepub const fn set_pre_charge_time(&mut self, val: u32)
pub const fn set_pre_charge_time(&mut self, val: u32)
Before detection, the top screen needs some time before being pulled up to a high voltage.